# coding: utf-8

"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from fluxoperator.configuration import Configuration


class MiniClusterContainer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'command': 'str',
        'commands': 'Commands',
        'cores': 'int',
        'diagnostics': 'bool',
        'environment': 'dict(str, str)',
        'flux_log_level': 'int',
        'flux_option_flags': 'str',
        'flux_user': 'FluxUser',
        'image': 'str',
        'image_pull_secret': 'str',
        'life_cycle': 'LifeCycle',
        'name': 'str',
        'ports': 'list[int]',
        'pre_command': 'str',
        'pull_always': 'bool',
        'resources': 'ContainerResources',
        'run_flux': 'bool',
        'volumes': 'dict(str, ContainerVolume)',
        'working_dir': 'str'
    }

    attribute_map = {
        'command': 'command',
        'commands': 'commands',
        'cores': 'cores',
        'diagnostics': 'diagnostics',
        'environment': 'environment',
        'flux_log_level': 'fluxLogLevel',
        'flux_option_flags': 'fluxOptionFlags',
        'flux_user': 'fluxUser',
        'image': 'image',
        'image_pull_secret': 'imagePullSecret',
        'life_cycle': 'lifeCycle',
        'name': 'name',
        'ports': 'ports',
        'pre_command': 'preCommand',
        'pull_always': 'pullAlways',
        'resources': 'resources',
        'run_flux': 'runFlux',
        'volumes': 'volumes',
        'working_dir': 'workingDir'
    }

    def __init__(self, command='', commands=None, cores=0, diagnostics=False, environment=None, flux_log_level=0, flux_option_flags='', flux_user=None, image='', image_pull_secret='', life_cycle=None, name='', ports=None, pre_command='', pull_always=False, resources=None, run_flux=False, volumes=None, working_dir='', local_vars_configuration=None):  # noqa: E501
        """MiniClusterContainer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._command = None
        self._commands = None
        self._cores = None
        self._diagnostics = None
        self._environment = None
        self._flux_log_level = None
        self._flux_option_flags = None
        self._flux_user = None
        self._image = None
        self._image_pull_secret = None
        self._life_cycle = None
        self._name = None
        self._ports = None
        self._pre_command = None
        self._pull_always = None
        self._resources = None
        self._run_flux = None
        self._volumes = None
        self._working_dir = None
        self.discriminator = None

        if command is not None:
            self.command = command
        if commands is not None:
            self.commands = commands
        if cores is not None:
            self.cores = cores
        if diagnostics is not None:
            self.diagnostics = diagnostics
        if environment is not None:
            self.environment = environment
        if flux_log_level is not None:
            self.flux_log_level = flux_log_level
        if flux_option_flags is not None:
            self.flux_option_flags = flux_option_flags
        if flux_user is not None:
            self.flux_user = flux_user
        self.image = image
        if image_pull_secret is not None:
            self.image_pull_secret = image_pull_secret
        if life_cycle is not None:
            self.life_cycle = life_cycle
        if name is not None:
            self.name = name
        if ports is not None:
            self.ports = ports
        if pre_command is not None:
            self.pre_command = pre_command
        if pull_always is not None:
            self.pull_always = pull_always
        if resources is not None:
            self.resources = resources
        if run_flux is not None:
            self.run_flux = run_flux
        if volumes is not None:
            self.volumes = volumes
        if working_dir is not None:
            self.working_dir = working_dir

    @property
    def command(self):
        """Gets the command of this MiniClusterContainer.  # noqa: E501

        Single user executable to provide to flux start IMPORTANT: This is left here, but not used in favor of exposing Flux via a Restful API. We Can remove this when that is finalized.  # noqa: E501

        :return: The command of this MiniClusterContainer.  # noqa: E501
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command):
        """Sets the command of this MiniClusterContainer.

        Single user executable to provide to flux start IMPORTANT: This is left here, but not used in favor of exposing Flux via a Restful API. We Can remove this when that is finalized.  # noqa: E501

        :param command: The command of this MiniClusterContainer.  # noqa: E501
        :type command: str
        """

        self._command = command

    @property
    def commands(self):
        """Gets the commands of this MiniClusterContainer.  # noqa: E501


        :return: The commands of this MiniClusterContainer.  # noqa: E501
        :rtype: Commands
        """
        return self._commands

    @commands.setter
    def commands(self, commands):
        """Sets the commands of this MiniClusterContainer.


        :param commands: The commands of this MiniClusterContainer.  # noqa: E501
        :type commands: Commands
        """

        self._commands = commands

    @property
    def cores(self):
        """Gets the cores of this MiniClusterContainer.  # noqa: E501

        Cores the container should use  # noqa: E501

        :return: The cores of this MiniClusterContainer.  # noqa: E501
        :rtype: int
        """
        return self._cores

    @cores.setter
    def cores(self, cores):
        """Sets the cores of this MiniClusterContainer.

        Cores the container should use  # noqa: E501

        :param cores: The cores of this MiniClusterContainer.  # noqa: E501
        :type cores: int
        """

        self._cores = cores

    @property
    def diagnostics(self):
        """Gets the diagnostics of this MiniClusterContainer.  # noqa: E501

        Run flux diagnostics on start instead of command  # noqa: E501

        :return: The diagnostics of this MiniClusterContainer.  # noqa: E501
        :rtype: bool
        """
        return self._diagnostics

    @diagnostics.setter
    def diagnostics(self, diagnostics):
        """Sets the diagnostics of this MiniClusterContainer.

        Run flux diagnostics on start instead of command  # noqa: E501

        :param diagnostics: The diagnostics of this MiniClusterContainer.  # noqa: E501
        :type diagnostics: bool
        """

        self._diagnostics = diagnostics

    @property
    def environment(self):
        """Gets the environment of this MiniClusterContainer.  # noqa: E501

        Key/value pairs for the environment  # noqa: E501

        :return: The environment of this MiniClusterContainer.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this MiniClusterContainer.

        Key/value pairs for the environment  # noqa: E501

        :param environment: The environment of this MiniClusterContainer.  # noqa: E501
        :type environment: dict(str, str)
        """

        self._environment = environment

    @property
    def flux_log_level(self):
        """Gets the flux_log_level of this MiniClusterContainer.  # noqa: E501

        Log level to use for flux logging (only in non TestMode)  # noqa: E501

        :return: The flux_log_level of this MiniClusterContainer.  # noqa: E501
        :rtype: int
        """
        return self._flux_log_level

    @flux_log_level.setter
    def flux_log_level(self, flux_log_level):
        """Sets the flux_log_level of this MiniClusterContainer.

        Log level to use for flux logging (only in non TestMode)  # noqa: E501

        :param flux_log_level: The flux_log_level of this MiniClusterContainer.  # noqa: E501
        :type flux_log_level: int
        """

        self._flux_log_level = flux_log_level

    @property
    def flux_option_flags(self):
        """Gets the flux_option_flags of this MiniClusterContainer.  # noqa: E501

        Flux option flags, usually provided with -o optional - if needed, default option flags for the server These can also be set in the user interface to override here. This is only valid for a FluxRunner \"runFlux\" true  # noqa: E501

        :return: The flux_option_flags of this MiniClusterContainer.  # noqa: E501
        :rtype: str
        """
        return self._flux_option_flags

    @flux_option_flags.setter
    def flux_option_flags(self, flux_option_flags):
        """Sets the flux_option_flags of this MiniClusterContainer.

        Flux option flags, usually provided with -o optional - if needed, default option flags for the server These can also be set in the user interface to override here. This is only valid for a FluxRunner \"runFlux\" true  # noqa: E501

        :param flux_option_flags: The flux_option_flags of this MiniClusterContainer.  # noqa: E501
        :type flux_option_flags: str
        """

        self._flux_option_flags = flux_option_flags

    @property
    def flux_user(self):
        """Gets the flux_user of this MiniClusterContainer.  # noqa: E501


        :return: The flux_user of this MiniClusterContainer.  # noqa: E501
        :rtype: FluxUser
        """
        return self._flux_user

    @flux_user.setter
    def flux_user(self, flux_user):
        """Sets the flux_user of this MiniClusterContainer.


        :param flux_user: The flux_user of this MiniClusterContainer.  # noqa: E501
        :type flux_user: FluxUser
        """

        self._flux_user = flux_user

    @property
    def image(self):
        """Gets the image of this MiniClusterContainer.  # noqa: E501

        Container image must contain flux and flux-sched install  # noqa: E501

        :return: The image of this MiniClusterContainer.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this MiniClusterContainer.

        Container image must contain flux and flux-sched install  # noqa: E501

        :param image: The image of this MiniClusterContainer.  # noqa: E501
        :type image: str
        """
        if self.local_vars_configuration.client_side_validation and image is None:  # noqa: E501
            raise ValueError("Invalid value for `image`, must not be `None`")  # noqa: E501

        self._image = image

    @property
    def image_pull_secret(self):
        """Gets the image_pull_secret of this MiniClusterContainer.  # noqa: E501

        Allow the user to pull authenticated images By default no secret is selected. Setting this with the name of an already existing imagePullSecret will specify that secret in the pod spec.  # noqa: E501

        :return: The image_pull_secret of this MiniClusterContainer.  # noqa: E501
        :rtype: str
        """
        return self._image_pull_secret

    @image_pull_secret.setter
    def image_pull_secret(self, image_pull_secret):
        """Sets the image_pull_secret of this MiniClusterContainer.

        Allow the user to pull authenticated images By default no secret is selected. Setting this with the name of an already existing imagePullSecret will specify that secret in the pod spec.  # noqa: E501

        :param image_pull_secret: The image_pull_secret of this MiniClusterContainer.  # noqa: E501
        :type image_pull_secret: str
        """

        self._image_pull_secret = image_pull_secret

    @property
    def life_cycle(self):
        """Gets the life_cycle of this MiniClusterContainer.  # noqa: E501


        :return: The life_cycle of this MiniClusterContainer.  # noqa: E501
        :rtype: LifeCycle
        """
        return self._life_cycle

    @life_cycle.setter
    def life_cycle(self, life_cycle):
        """Sets the life_cycle of this MiniClusterContainer.


        :param life_cycle: The life_cycle of this MiniClusterContainer.  # noqa: E501
        :type life_cycle: LifeCycle
        """

        self._life_cycle = life_cycle

    @property
    def name(self):
        """Gets the name of this MiniClusterContainer.  # noqa: E501

        Container name is only required for non flux runners  # noqa: E501

        :return: The name of this MiniClusterContainer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MiniClusterContainer.

        Container name is only required for non flux runners  # noqa: E501

        :param name: The name of this MiniClusterContainer.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def ports(self):
        """Gets the ports of this MiniClusterContainer.  # noqa: E501

        Ports to be exposed to other containers in the cluster We take a single list of integers and map to the same  # noqa: E501

        :return: The ports of this MiniClusterContainer.  # noqa: E501
        :rtype: list[int]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this MiniClusterContainer.

        Ports to be exposed to other containers in the cluster We take a single list of integers and map to the same  # noqa: E501

        :param ports: The ports of this MiniClusterContainer.  # noqa: E501
        :type ports: list[int]
        """

        self._ports = ports

    @property
    def pre_command(self):
        """Gets the pre_command of this MiniClusterContainer.  # noqa: E501

        Special command to run at beginning of script, directly after asFlux is defined as sudo -u flux -E (so you can change that if desired.) This is only valid if FluxRunner is set (that writes a wait.sh script) This is for the indexed job pods and the certificate generation container.  # noqa: E501

        :return: The pre_command of this MiniClusterContainer.  # noqa: E501
        :rtype: str
        """
        return self._pre_command

    @pre_command.setter
    def pre_command(self, pre_command):
        """Sets the pre_command of this MiniClusterContainer.

        Special command to run at beginning of script, directly after asFlux is defined as sudo -u flux -E (so you can change that if desired.) This is only valid if FluxRunner is set (that writes a wait.sh script) This is for the indexed job pods and the certificate generation container.  # noqa: E501

        :param pre_command: The pre_command of this MiniClusterContainer.  # noqa: E501
        :type pre_command: str
        """

        self._pre_command = pre_command

    @property
    def pull_always(self):
        """Gets the pull_always of this MiniClusterContainer.  # noqa: E501

        Allow the user to dictate pulling By default we pull if not present. Setting this to true will indicate to pull always  # noqa: E501

        :return: The pull_always of this MiniClusterContainer.  # noqa: E501
        :rtype: bool
        """
        return self._pull_always

    @pull_always.setter
    def pull_always(self, pull_always):
        """Sets the pull_always of this MiniClusterContainer.

        Allow the user to dictate pulling By default we pull if not present. Setting this to true will indicate to pull always  # noqa: E501

        :param pull_always: The pull_always of this MiniClusterContainer.  # noqa: E501
        :type pull_always: bool
        """

        self._pull_always = pull_always

    @property
    def resources(self):
        """Gets the resources of this MiniClusterContainer.  # noqa: E501


        :return: The resources of this MiniClusterContainer.  # noqa: E501
        :rtype: ContainerResources
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this MiniClusterContainer.


        :param resources: The resources of this MiniClusterContainer.  # noqa: E501
        :type resources: ContainerResources
        """

        self._resources = resources

    @property
    def run_flux(self):
        """Gets the run_flux of this MiniClusterContainer.  # noqa: E501

        Main container to run flux (only should be one)  # noqa: E501

        :return: The run_flux of this MiniClusterContainer.  # noqa: E501
        :rtype: bool
        """
        return self._run_flux

    @run_flux.setter
    def run_flux(self, run_flux):
        """Sets the run_flux of this MiniClusterContainer.

        Main container to run flux (only should be one)  # noqa: E501

        :param run_flux: The run_flux of this MiniClusterContainer.  # noqa: E501
        :type run_flux: bool
        """

        self._run_flux = run_flux

    @property
    def volumes(self):
        """Gets the volumes of this MiniClusterContainer.  # noqa: E501

        Volumes that can be mounted (must be defined in volumes)  # noqa: E501

        :return: The volumes of this MiniClusterContainer.  # noqa: E501
        :rtype: dict(str, ContainerVolume)
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this MiniClusterContainer.

        Volumes that can be mounted (must be defined in volumes)  # noqa: E501

        :param volumes: The volumes of this MiniClusterContainer.  # noqa: E501
        :type volumes: dict(str, ContainerVolume)
        """

        self._volumes = volumes

    @property
    def working_dir(self):
        """Gets the working_dir of this MiniClusterContainer.  # noqa: E501

        Working directory to run command from  # noqa: E501

        :return: The working_dir of this MiniClusterContainer.  # noqa: E501
        :rtype: str
        """
        return self._working_dir

    @working_dir.setter
    def working_dir(self, working_dir):
        """Sets the working_dir of this MiniClusterContainer.

        Working directory to run command from  # noqa: E501

        :param working_dir: The working_dir of this MiniClusterContainer.  # noqa: E501
        :type working_dir: str
        """

        self._working_dir = working_dir

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MiniClusterContainer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MiniClusterContainer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import fluxoperator
from fluxoperator.models.mini_cluster import MiniCluster  # noqa: E501
from fluxoperator.rest import ApiException

class TestMiniCluster(unittest.TestCase):
    """MiniCluster unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MiniCluster
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = fluxoperator.models.mini_cluster.MiniCluster()  # noqa: E501
        if include_optional :
            return MiniCluster(
                api_version = '', 
                kind = '', 
                metadata = None, 
                spec = fluxoperator.models.mini_cluster_spec.MiniClusterSpec(
                    cleanup = True, 
                    containers = [
                        fluxoperator.models.mini_cluster_container.MiniClusterContainer(
                            command = '', 
                            commands = fluxoperator.models.commands.Commands(
                                pre = '', 
                                run_flux_as_root = True, ), 
                            cores = 56, 
                            diagnostics = True, 
                            environment = {
                                'key' : ''
                                }, 
                            flux_log_level = 56, 
                            flux_option_flags = '', 
                            flux_user = fluxoperator.models.flux_user.FluxUser(
                                name = '', 
                                uid = 56, ), 
                            image = '', 
                            image_pull_secret = '', 
                            life_cycle = fluxoperator.models.life_cycle.LifeCycle(
                                post_start_exec = '', ), 
                            name = '', 
                            ports = [
                                56
                                ], 
                            pre_command = '', 
                            pull_always = True, 
                            resources = fluxoperator.models.container_resources.ContainerResources(
                                limits = {
                                    'key' : None
                                    }, 
                                requests = {
                                    'key' : None
                                    }, ), 
                            run_flux = True, 
                            volumes = {
                                'key' : fluxoperator.models.container_volume.ContainerVolume(
                                    path = '', 
                                    read_only = True, )
                                }, 
                            working_dir = '', )
                        ], 
                    deadline_seconds = 56, 
                    flux_restful = fluxoperator.models.flux_restful.FluxRestful(
                        branch = '', 
                        port = 56, 
                        token = '', 
                        username = '', ), 
                    job_labels = {
                        'key' : ''
                        }, 
                    logging = fluxoperator.models.logging_spec.LoggingSpec(
                        debug = True, 
                        quiet = True, 
                        strict = True, 
                        timed = True, ), 
                    pod = fluxoperator.models.pod_spec.PodSpec(
                        annotations = {
                            'key' : ''
                            }, 
                        labels = {
                            'key' : ''
                            }, ), 
                    size = 56, 
                    tasks = 56, 
                    users = [
                        fluxoperator.models.mini_cluster_user.MiniClusterUser(
                            name = '', 
                            password = '', )
                        ], 
                    volumes = {
                        'key' : fluxoperator.models.mini_cluster_volume.MiniClusterVolume(
                            capacity = '', 
                            path = '', 
                            secret = '', 
                            secret_namespace = '', 
                            storage_class = '', )
                        }, ), 
                status = fluxoperator.models.mini_cluster_status.MiniClusterStatus(
                    conditions = [
                        None
                        ], 
                    jobid = '', )
            )
        else :
            return MiniCluster(
        )

    def testMiniCluster(self):
        """Test MiniCluster"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import fluxoperator
from fluxoperator.models.mini_cluster_list import MiniClusterList  # noqa: E501
from fluxoperator.rest import ApiException

class TestMiniClusterList(unittest.TestCase):
    """MiniClusterList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MiniClusterList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = fluxoperator.models.mini_cluster_list.MiniClusterList()  # noqa: E501
        if include_optional :
            return MiniClusterList(
                api_version = '', 
                items = [
                    fluxoperator.models.mini_cluster.MiniCluster(
                        api_version = '', 
                        kind = '', 
                        metadata = None, 
                        spec = fluxoperator.models.mini_cluster_spec.MiniClusterSpec(
                            cleanup = True, 
                            containers = [
                                fluxoperator.models.mini_cluster_container.MiniClusterContainer(
                                    command = '', 
                                    commands = fluxoperator.models.commands.Commands(
                                        pre = '', 
                                        run_flux_as_root = True, ), 
                                    cores = 56, 
                                    diagnostics = True, 
                                    environment = {
                                        'key' : ''
                                        }, 
                                    flux_log_level = 56, 
                                    flux_option_flags = '', 
                                    flux_user = fluxoperator.models.flux_user.FluxUser(
                                        name = '', 
                                        uid = 56, ), 
                                    image = '', 
                                    image_pull_secret = '', 
                                    life_cycle = fluxoperator.models.life_cycle.LifeCycle(
                                        post_start_exec = '', ), 
                                    name = '', 
                                    ports = [
                                        56
                                        ], 
                                    pre_command = '', 
                                    pull_always = True, 
                                    resources = fluxoperator.models.container_resources.ContainerResources(
                                        limits = {
                                            'key' : None
                                            }, 
                                        requests = {
                                            'key' : None
                                            }, ), 
                                    run_flux = True, 
                                    volumes = {
                                        'key' : fluxoperator.models.container_volume.ContainerVolume(
                                            path = '', 
                                            read_only = True, )
                                        }, 
                                    working_dir = '', )
                                ], 
                            deadline_seconds = 56, 
                            flux_restful = fluxoperator.models.flux_restful.FluxRestful(
                                branch = '', 
                                port = 56, 
                                token = '', 
                                username = '', ), 
                            job_labels = {
                                'key' : ''
                                }, 
                            logging = fluxoperator.models.logging_spec.LoggingSpec(
                                debug = True, 
                                quiet = True, 
                                strict = True, 
                                timed = True, ), 
                            pod = fluxoperator.models.pod_spec.PodSpec(
                                annotations = {
                                    'key' : ''
                                    }, 
                                labels = {
                                    'key' : ''
                                    }, ), 
                            size = 56, 
                            tasks = 56, 
                            users = [
                                fluxoperator.models.mini_cluster_user.MiniClusterUser(
                                    name = '', 
                                    password = '', )
                                ], 
                            volumes = {
                                'key' : fluxoperator.models.mini_cluster_volume.MiniClusterVolume(
                                    capacity = '', 
                                    path = '', 
                                    secret = '', 
                                    secret_namespace = '', 
                                    storage_class = '', )
                                }, ), 
                        status = fluxoperator.models.mini_cluster_status.MiniClusterStatus(
                            conditions = [
                                None
                                ], 
                            jobid = '', ), )
                    ], 
                kind = '', 
                metadata = None
            )
        else :
            return MiniClusterList(
                items = [
                    fluxoperator.models.mini_cluster.MiniCluster(
                        api_version = '', 
                        kind = '', 
                        metadata = None, 
                        spec = fluxoperator.models.mini_cluster_spec.MiniClusterSpec(
                            cleanup = True, 
                            containers = [
                                fluxoperator.models.mini_cluster_container.MiniClusterContainer(
                                    command = '', 
                                    commands = fluxoperator.models.commands.Commands(
                                        pre = '', 
                                        run_flux_as_root = True, ), 
                                    cores = 56, 
                                    diagnostics = True, 
                                    environment = {
                                        'key' : ''
                                        }, 
                                    flux_log_level = 56, 
                                    flux_option_flags = '', 
                                    flux_user = fluxoperator.models.flux_user.FluxUser(
                                        name = '', 
                                        uid = 56, ), 
                                    image = '', 
                                    image_pull_secret = '', 
                                    life_cycle = fluxoperator.models.life_cycle.LifeCycle(
                                        post_start_exec = '', ), 
                                    name = '', 
                                    ports = [
                                        56
                                        ], 
                                    pre_command = '', 
                                    pull_always = True, 
                                    resources = fluxoperator.models.container_resources.ContainerResources(
                                        limits = {
                                            'key' : None
                                            }, 
                                        requests = {
                                            'key' : None
                                            }, ), 
                                    run_flux = True, 
                                    volumes = {
                                        'key' : fluxoperator.models.container_volume.ContainerVolume(
                                            path = '', 
                                            read_only = True, )
                                        }, 
                                    working_dir = '', )
                                ], 
                            deadline_seconds = 56, 
                            flux_restful = fluxoperator.models.flux_restful.FluxRestful(
                                branch = '', 
                                port = 56, 
                                token = '', 
                                username = '', ), 
                            job_labels = {
                                'key' : ''
                                }, 
                            logging = fluxoperator.models.logging_spec.LoggingSpec(
                                debug = True, 
                                quiet = True, 
                                strict = True, 
                                timed = True, ), 
                            pod = fluxoperator.models.pod_spec.PodSpec(
                                annotations = {
                                    'key' : ''
                                    }, 
                                labels = {
                                    'key' : ''
                                    }, ), 
                            size = 56, 
                            tasks = 56, 
                            users = [
                                fluxoperator.models.mini_cluster_user.MiniClusterUser(
                                    name = '', 
                                    password = '', )
                                ], 
                            volumes = {
                                'key' : fluxoperator.models.mini_cluster_volume.MiniClusterVolume(
                                    capacity = '', 
                                    path = '', 
                                    secret = '', 
                                    secret_namespace = '', 
                                    storage_class = '', )
                                }, ), 
                        status = fluxoperator.models.mini_cluster_status.MiniClusterStatus(
                            conditions = [
                                None
                                ], 
                            jobid = '', ), )
                    ],
        )

    def testMiniClusterList(self):
        """Test MiniClusterList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import fluxoperator
from fluxoperator.models.mini_cluster_spec import MiniClusterSpec  # noqa: E501
from fluxoperator.rest import ApiException

class TestMiniClusterSpec(unittest.TestCase):
    """MiniClusterSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MiniClusterSpec
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = fluxoperator.models.mini_cluster_spec.MiniClusterSpec()  # noqa: E501
        if include_optional :
            return MiniClusterSpec(
                cleanup = True, 
                containers = [
                    fluxoperator.models.mini_cluster_container.MiniClusterContainer(
                        command = '', 
                        commands = fluxoperator.models.commands.Commands(
                            pre = '', 
                            run_flux_as_root = True, ), 
                        cores = 56, 
                        diagnostics = True, 
                        environment = {
                            'key' : ''
                            }, 
                        flux_log_level = 56, 
                        flux_option_flags = '', 
                        flux_user = fluxoperator.models.flux_user.FluxUser(
                            name = '', 
                            uid = 56, ), 
                        image = '', 
                        image_pull_secret = '', 
                        life_cycle = fluxoperator.models.life_cycle.LifeCycle(
                            post_start_exec = '', ), 
                        name = '', 
                        ports = [
                            56
                            ], 
                        pre_command = '', 
                        pull_always = True, 
                        resources = fluxoperator.models.container_resources.ContainerResources(
                            limits = {
                                'key' : None
                                }, 
                            requests = {
                                'key' : None
                                }, ), 
                        run_flux = True, 
                        volumes = {
                            'key' : fluxoperator.models.container_volume.ContainerVolume(
                                path = '', 
                                read_only = True, )
                            }, 
                        working_dir = '', )
                    ], 
                deadline_seconds = 56, 
                flux_restful = fluxoperator.models.flux_restful.FluxRestful(
                    branch = '', 
                    port = 56, 
                    token = '', 
                    username = '', ), 
                job_labels = {
                    'key' : ''
                    }, 
                logging = fluxoperator.models.logging_spec.LoggingSpec(
                    debug = True, 
                    quiet = True, 
                    strict = True, 
                    timed = True, ), 
                pod = fluxoperator.models.pod_spec.PodSpec(
                    annotations = {
                        'key' : ''
                        }, 
                    labels = {
                        'key' : ''
                        }, 
                    resources = {
                        'key' : None
                        }, ), 
                size = 56, 
                tasks = 56, 
                users = [
                    fluxoperator.models.mini_cluster_user.MiniClusterUser(
                        name = '', 
                        password = '', )
                    ], 
                volumes = {
                    'key' : fluxoperator.models.mini_cluster_volume.MiniClusterVolume(
                        annotations = {
                            'key' : ''
                            }, 
                        capacity = '', 
                        labels = {
                            'key' : ''
                            }, 
                        path = '', 
                        secret = '', 
                        secret_namespace = '', 
                        storage_class = '', )
                    }
            )
        else :
            return MiniClusterSpec(
                containers = [
                    fluxoperator.models.mini_cluster_container.MiniClusterContainer(
                        command = '', 
                        commands = fluxoperator.models.commands.Commands(
                            pre = '', 
                            run_flux_as_root = True, ), 
                        cores = 56, 
                        diagnostics = True, 
                        environment = {
                            'key' : ''
                            }, 
                        flux_log_level = 56, 
                        flux_option_flags = '', 
                        flux_user = fluxoperator.models.flux_user.FluxUser(
                            name = '', 
                            uid = 56, ), 
                        image = '', 
                        image_pull_secret = '', 
                        life_cycle = fluxoperator.models.life_cycle.LifeCycle(
                            post_start_exec = '', ), 
                        name = '', 
                        ports = [
                            56
                            ], 
                        pre_command = '', 
                        pull_always = True, 
                        resources = fluxoperator.models.container_resources.ContainerResources(
                            limits = {
                                'key' : None
                                }, 
                            requests = {
                                'key' : None
                                }, ), 
                        run_flux = True, 
                        volumes = {
                            'key' : fluxoperator.models.container_volume.ContainerVolume(
                                path = '', 
                                read_only = True, )
                            }, 
                        working_dir = '', )
                    ],
        )

    def testMiniClusterSpec(self):
        """Test MiniClusterSpec"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from fluxoperator.models.commands import Commands
from fluxoperator.models.container_resources import ContainerResources
from fluxoperator.models.container_volume import ContainerVolume
from fluxoperator.models.flux_restful import FluxRestful
from fluxoperator.models.flux_user import FluxUser
from fluxoperator.models.life_cycle import LifeCycle
from fluxoperator.models.logging_spec import LoggingSpec
from fluxoperator.models.mini_cluster import MiniCluster
from fluxoperator.models.mini_cluster_container import MiniClusterContainer
from fluxoperator.models.mini_cluster_list import MiniClusterList
from fluxoperator.models.mini_cluster_spec import MiniClusterSpec
from fluxoperator.models.mini_cluster_status import MiniClusterStatus
from fluxoperator.models.mini_cluster_user import MiniClusterUser
from fluxoperator.models.mini_cluster_volume import MiniClusterVolume
from fluxoperator.models.pod_spec import PodSpec



# coding: utf-8

# flake8: noqa

"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.0.0"

# import apis into sdk package

# import ApiClient
from fluxoperator.api_client import ApiClient
from fluxoperator.configuration import Configuration
from fluxoperator.exceptions import OpenApiException
from fluxoperator.exceptions import ApiTypeError
from fluxoperator.exceptions import ApiValueError
from fluxoperator.exceptions import ApiKeyError
from fluxoperator.exceptions import ApiAttributeError
from fluxoperator.exceptions import ApiException
# import models into sdk package
from fluxoperator.models.commands import Commands
from fluxoperator.models.container_resources import ContainerResources
from fluxoperator.models.container_volume import ContainerVolume
from fluxoperator.models.flux_restful import FluxRestful
from fluxoperator.models.flux_user import FluxUser
from fluxoperator.models.life_cycle import LifeCycle
from fluxoperator.models.logging_spec import LoggingSpec
from fluxoperator.models.mini_cluster import MiniCluster
from fluxoperator.models.mini_cluster_container import MiniClusterContainer
from fluxoperator.models.mini_cluster_list import MiniClusterList
from fluxoperator.models.mini_cluster_spec import MiniClusterSpec
from fluxoperator.models.mini_cluster_status import MiniClusterStatus
from fluxoperator.models.mini_cluster_user import MiniClusterUser
from fluxoperator.models.mini_cluster_volume import MiniClusterVolume
from fluxoperator.models.pod_spec import PodSpec




# coding: utf-8

"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from fluxoperator.configuration import Configuration


class LoggingSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'debug': 'bool',
        'quiet': 'bool',
        'strict': 'bool',
        'timed': 'bool'
    }

    attribute_map = {
        'debug': 'debug',
        'quiet': 'quiet',
        'strict': 'strict',
        'timed': 'timed'
    }

    def __init__(self, debug=False, quiet=False, strict=False, timed=False, local_vars_configuration=None):  # noqa: E501
        """LoggingSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._debug = None
        self._quiet = None
        self._strict = None
        self._timed = None
        self.discriminator = None

        if debug is not None:
            self.debug = debug
        if quiet is not None:
            self.quiet = quiet
        if strict is not None:
            self.strict = strict
        if timed is not None:
            self.timed = timed

    @property
    def debug(self):
        """Gets the debug of this LoggingSpec.  # noqa: E501

        Debug mode adds extra verbosity to Flux  # noqa: E501

        :return: The debug of this LoggingSpec.  # noqa: E501
        :rtype: bool
        """
        return self._debug

    @debug.setter
    def debug(self, debug):
        """Sets the debug of this LoggingSpec.

        Debug mode adds extra verbosity to Flux  # noqa: E501

        :param debug: The debug of this LoggingSpec.  # noqa: E501
        :type debug: bool
        """

        self._debug = debug

    @property
    def quiet(self):
        """Gets the quiet of this LoggingSpec.  # noqa: E501

        Quiet mode silences all output so the job only shows the test running  # noqa: E501

        :return: The quiet of this LoggingSpec.  # noqa: E501
        :rtype: bool
        """
        return self._quiet

    @quiet.setter
    def quiet(self, quiet):
        """Sets the quiet of this LoggingSpec.

        Quiet mode silences all output so the job only shows the test running  # noqa: E501

        :param quiet: The quiet of this LoggingSpec.  # noqa: E501
        :type quiet: bool
        """

        self._quiet = quiet

    @property
    def strict(self):
        """Gets the strict of this LoggingSpec.  # noqa: E501

        Strict mode ensures any failure will not continue in the job entrypoint  # noqa: E501

        :return: The strict of this LoggingSpec.  # noqa: E501
        :rtype: bool
        """
        return self._strict

    @strict.setter
    def strict(self, strict):
        """Sets the strict of this LoggingSpec.

        Strict mode ensures any failure will not continue in the job entrypoint  # noqa: E501

        :param strict: The strict of this LoggingSpec.  # noqa: E501
        :type strict: bool
        """

        self._strict = strict

    @property
    def timed(self):
        """Gets the timed of this LoggingSpec.  # noqa: E501

        Timed mode adds timing to Flux commands  # noqa: E501

        :return: The timed of this LoggingSpec.  # noqa: E501
        :rtype: bool
        """
        return self._timed

    @timed.setter
    def timed(self, timed):
        """Sets the timed of this LoggingSpec.

        Timed mode adds timing to Flux commands  # noqa: E501

        :param timed: The timed of this LoggingSpec.  # noqa: E501
        :type timed: bool
        """

        self._timed = timed

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LoggingSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LoggingSpec):
            return True

        return self.to_dict() != other.to_dict()



from kubernetes import client
from kubernetes.client.api import core_v1_api
from contextlib import contextmanager
from .resource.network import port_forward

import requests
import time


class FluxOperator:
    def __init__(self, namespace):
        """
        Create a persistent client to interact with a MiniCluster

        This currently assumes the namespace exists.
        """
        self.namespace = namespace
        self.c = client.Configuration.get_default_copy()
        self.c.assert_hostname = False
        client.Configuration.set_default(self.c)
        self.core_v1 = core_v1_api.CoreV1Api()

    @contextmanager
    def port_forward(self, pod):
        """
        Wrapper to the port forward with context
        """
        with port_forward(self.core_v1):
            # Wait until this url is actually ready. In practice about 10-15 seconds
            url = f"http://{pod.metadata.name}.pod.flux-operator.kubernetes:5000"
            print()
            print(f"Waiting for {url} to be ready")
            sleep = 2
            ready = False
            while not ready:
                time.sleep(sleep)
                try:
                    response = requests.get(url)
                    if response.status_code == 200:
                        print("🪅️ RestFUL API server is ready!")
                        ready = True

                # There will be a few connection errors before everything is ready
                except Exception:
                    pass
                print(".", end="\r")
                sleep = sleep * 2

            print()
            yield url

    def wait_pods(self):
        """
        Wait for all pods to be running or completed
        """
        ready = False
        while not ready:
            pod_list = self.core_v1.list_namespaced_pod(self.namespace)
            ready = False
            for pod in pod_list.items:
                if pod.status.phase not in ["Running", "Completed"]:
                    time.sleep(2)
                    continue
            # If we get down here, pods are ready
            ready = True

        print('All pods are "Running" or "Completed"')

    def get_broker_pod(self):
        """
        Given a core_v1 connection and namespace, get the broker pod.
        """
        # All pods required to be ready
        self.wait_pods()

        # Go through process again and get broker
        brokerPod = None
        while not brokerPod:
            pod_list = self.core_v1.list_namespaced_pod(self.namespace)
            for pod in pod_list.items:
                if "-0" in pod.metadata.name:
                    print(f"Found broker pod {pod.metadata.name}")
                    brokerPod = pod
        return brokerPod



# coding: utf-8

"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import fluxoperator
from fluxoperator.models.mini_cluster_container import MiniClusterContainer  # noqa: E501
from fluxoperator.rest import ApiException

class TestMiniClusterContainer(unittest.TestCase):
    """MiniClusterContainer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MiniClusterContainer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = fluxoperator.models.mini_cluster_container.MiniClusterContainer()  # noqa: E501
        if include_optional :
            return MiniClusterContainer(
                command = '', 
                commands = fluxoperator.models.commands.Commands(
                    pre = '', 
                    run_flux_as_root = True, ), 
                cores = 56, 
                diagnostics = True, 
                environment = {
                    'key' : ''
                    }, 
                flux_log_level = 56, 
                flux_option_flags = '', 
                flux_user = fluxoperator.models.flux_user.FluxUser(
                    name = '', 
                    uid = 56, ), 
                image = '', 
                image_pull_secret = '', 
                life_cycle = fluxoperator.models.life_cycle.LifeCycle(
                    post_start_exec = '', ), 
                name = '', 
                ports = [
                    56
                    ], 
                pre_command = '', 
                pull_always = True, 
                resources = fluxoperator.models.container_resources.ContainerResources(
                    limits = {
                        'key' : None
                        }, 
                    requests = {
                        'key' : None
                        }, ), 
                run_flux = True, 
                volumes = {
                    'key' : fluxoperator.models.container_volume.ContainerVolume(
                        path = '', 
                        read_only = True, )
                    }, 
                working_dir = ''
            )
        else :
            return MiniClusterContainer(
                image = '',
        )

    def testMiniClusterContainer(self):
        """Test MiniClusterContainer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



from kubernetes.stream import portforward
from contextlib import contextmanager

import urllib3


@contextmanager
def port_forward(core_v1, *args, **kwds):
    """
    Create context (with statement) to temporarily monkey patch socket.create_connection.
    """
    # Keep a handle on the old connection
    socket_create_connection = urllib3.util.connection.create_connection

    def kubernetes_create_connection(address, *args, **kwargs):
        """
        Function provided to urllib3.util.connection.create_connection.
        """
        # Ensure the request is for kubernetes
        # otherwise handle connection with original urllib3 create_connection
        dns_name = address[0]
        if isinstance(dns_name, bytes):
            dns_name = dns_name.decode()
        dns_name = dns_name.split(".")
        if dns_name[-1] != "kubernetes":
            return socket_create_connection(address, *args, **kwargs)

        # requred to be <pod-name>.pod.<namespace>.kubernetes
        if len(dns_name) not in (3, 4):
            raise RuntimeError("Unexpected kubernetes DNS name.")

        # Sploot out pieces we want to interact with
        namespace = dns_name[-2]
        name = dns_name[0]
        port = address[1]

        # This is currently only supporting pods, we have service across
        if len(dns_name) == 4:
            if dns_name[1] != "pod":
                raise RuntimeError("port-forward currently just supports pods.")
        pf = portforward(
            core_v1.connect_get_namespaced_pod_portforward,
            name,
            namespace,
            ports=str(port),
        )
        return pf.socket(port)

    try:
        # Do the monkey patch
        urllib3.util.connection.create_connection = kubernetes_create_connection
        yield
    finally:
        # Undo the monkey patch
        urllib3.util.connection.create_connection = socket_create_connection



# coding: utf-8

"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import fluxoperator
from fluxoperator.models.life_cycle import LifeCycle  # noqa: E501
from fluxoperator.rest import ApiException

class TestLifeCycle(unittest.TestCase):
    """LifeCycle unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test LifeCycle
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = fluxoperator.models.life_cycle.LifeCycle()  # noqa: E501
        if include_optional :
            return LifeCycle(
                post_start_exec = ''
            )
        else :
            return LifeCycle(
        )

    def testLifeCycle(self):
        """Test LifeCycle"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""

import os

from setuptools import find_packages, setup  # noqa: H301

# Make sure everything is relative to setup.py
install_path = os.path.dirname(os.path.abspath(__file__))
os.chdir(install_path)

DESCRIPTION = "Python SDK for the Flux Operator"
# Try to read description, otherwise fallback to short description
try:
    with open(os.path.join("docs", "README.md")) as filey:
        LONG_DESCRIPTION = filey.read()
except Exception:
    LONG_DESCRIPTION = DESCRIPTION

################################################################################
# MAIN #########################################################################
################################################################################

if __name__ == "__main__":
    setup(
        name="fluxoperator",
        version="0.0.1",
        author="Vanessasaurus",
        author_email="vsoch@users.noreply.github.com",
        maintainer="Vanessasaurus",
        packages=find_packages(),
        include_package_data=True,
        zip_safe=False,
        url="https://github.com/flux-framework/flux-operator/tree/main/python-sdk/v1alpha1",
        license="Apache 2.0",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        long_description_content_type="text/markdown",
        keywords="flux-operator,flux-framework,kubernetes,workflows,jobs-api",
        setup_requires=["pytest-runner"],
        install_requires=["kubernetes", "requests"],
        tests_require=["pytest", "pytest-cov"],
        classifiers=[
            "Intended Audience :: Science/Research",
            "Intended Audience :: Developers",
            "License :: OSI Approved :: Apache Software License",
            "Programming Language :: C",
            "Programming Language :: Python",
            "Topic :: Software Development",
            "Topic :: Scientific/Engineering",
            "Operating System :: Unix",
            "Programming Language :: Python :: 3.7",
        ],
    )



# coding: utf-8

"""
    fluxoperator

    Python SDK for Flux-Operator  # noqa: E501

    The version of the OpenAPI document: v1alpha1
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from fluxoperator.configuration import Configuration


class MiniClusterSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cleanup': 'bool',
        'containers': 'list[MiniClusterContainer]',
        'deadline_seconds': 'int',
        'flux_restful': 'FluxRestful',
        'job_labels': 'dict(str, str)',
        'logging': 'LoggingSpec',
        'pod': 'PodSpec',
        'size': 'int',
        'tasks': 'int',
        'users': 'list[MiniClusterUser]',
        'volumes': 'dict(str, MiniClusterVolume)'
    }

    attribute_map = {
        'cleanup': 'cleanup',
        'containers': 'containers',
        'deadline_seconds': 'deadlineSeconds',
        'flux_restful': 'fluxRestful',
        'job_labels': 'jobLabels',
        'logging': 'logging',
        'pod': 'pod',
        'size': 'size',
        'tasks': 'tasks',
        'users': 'users',
        'volumes': 'volumes'
    }

    def __init__(self, cleanup=False, containers=None, deadline_seconds=0, flux_restful=None, job_labels=None, logging=None, pod=None, size=0, tasks=0, users=None, volumes=None, local_vars_configuration=None):  # noqa: E501
        """MiniClusterSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._cleanup = None
        self._containers = None
        self._deadline_seconds = None
        self._flux_restful = None
        self._job_labels = None
        self._logging = None
        self._pod = None
        self._size = None
        self._tasks = None
        self._users = None
        self._volumes = None
        self.discriminator = None

        if cleanup is not None:
            self.cleanup = cleanup
        self.containers = containers
        if deadline_seconds is not None:
            self.deadline_seconds = deadline_seconds
        if flux_restful is not None:
            self.flux_restful = flux_restful
        if job_labels is not None:
            self.job_labels = job_labels
        if logging is not None:
            self.logging = logging
        if pod is not None:
            self.pod = pod
        if size is not None:
            self.size = size
        if tasks is not None:
            self.tasks = tasks
        if users is not None:
            self.users = users
        if volumes is not None:
            self.volumes = volumes

    @property
    def cleanup(self):
        """Gets the cleanup of this MiniClusterSpec.  # noqa: E501

        Cleanup the pods and storage when the index broker pod is complete  # noqa: E501

        :return: The cleanup of this MiniClusterSpec.  # noqa: E501
        :rtype: bool
        """
        return self._cleanup

    @cleanup.setter
    def cleanup(self, cleanup):
        """Sets the cleanup of this MiniClusterSpec.

        Cleanup the pods and storage when the index broker pod is complete  # noqa: E501

        :param cleanup: The cleanup of this MiniClusterSpec.  # noqa: E501
        :type cleanup: bool
        """

        self._cleanup = cleanup

    @property
    def containers(self):
        """Gets the containers of this MiniClusterSpec.  # noqa: E501

        Containers is one or more containers to be created in a pod. There should only be one container to run flux with runFlux  # noqa: E501

        :return: The containers of this MiniClusterSpec.  # noqa: E501
        :rtype: list[MiniClusterContainer]
        """
        return self._containers

    @containers.setter
    def containers(self, containers):
        """Sets the containers of this MiniClusterSpec.

        Containers is one or more containers to be created in a pod. There should only be one container to run flux with runFlux  # noqa: E501

        :param containers: The containers of this MiniClusterSpec.  # noqa: E501
        :type containers: list[MiniClusterContainer]
        """
        if self.local_vars_configuration.client_side_validation and containers is None:  # noqa: E501
            raise ValueError("Invalid value for `containers`, must not be `None`")  # noqa: E501

        self._containers = containers

    @property
    def deadline_seconds(self):
        """Gets the deadline_seconds of this MiniClusterSpec.  # noqa: E501

        Should the job be limited to a particular number of seconds? Approximately one year. This cannot be zero or job won't start  # noqa: E501

        :return: The deadline_seconds of this MiniClusterSpec.  # noqa: E501
        :rtype: int
        """
        return self._deadline_seconds

    @deadline_seconds.setter
    def deadline_seconds(self, deadline_seconds):
        """Sets the deadline_seconds of this MiniClusterSpec.

        Should the job be limited to a particular number of seconds? Approximately one year. This cannot be zero or job won't start  # noqa: E501

        :param deadline_seconds: The deadline_seconds of this MiniClusterSpec.  # noqa: E501
        :type deadline_seconds: int
        """

        self._deadline_seconds = deadline_seconds

    @property
    def flux_restful(self):
        """Gets the flux_restful of this MiniClusterSpec.  # noqa: E501


        :return: The flux_restful of this MiniClusterSpec.  # noqa: E501
        :rtype: FluxRestful
        """
        return self._flux_restful

    @flux_restful.setter
    def flux_restful(self, flux_restful):
        """Sets the flux_restful of this MiniClusterSpec.


        :param flux_restful: The flux_restful of this MiniClusterSpec.  # noqa: E501
        :type flux_restful: FluxRestful
        """

        self._flux_restful = flux_restful

    @property
    def job_labels(self):
        """Gets the job_labels of this MiniClusterSpec.  # noqa: E501

        Labels for the job  # noqa: E501

        :return: The job_labels of this MiniClusterSpec.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._job_labels

    @job_labels.setter
    def job_labels(self, job_labels):
        """Sets the job_labels of this MiniClusterSpec.

        Labels for the job  # noqa: E501

        :param job_labels: The job_labels of this MiniClusterSpec.  # noqa: E501
        :type job_labels: dict(str, str)
        """

        self._job_labels = job_labels

    @property
    def logging(self):
        """Gets the logging of this MiniClusterSpec.  # noqa: E501


        :return: The logging of this MiniClusterSpec.  # noqa: E501
        :rtype: LoggingSpec
        """
        return self._logging

    @logging.setter
    def logging(self, logging):
        """Sets the logging of this MiniClusterSpec.


        :param logging: The logging of this MiniClusterSpec.  # noqa: E501
        :type logging: LoggingSpec
        """

        self._logging = logging

    @property
    def pod(self):
        """Gets the pod of this MiniClusterSpec.  # noqa: E501


        :return: The pod of this MiniClusterSpec.  # noqa: E501
        :rtype: PodSpec
        """
        return self._pod

    @pod.setter
    def pod(self, pod):
        """Sets the pod of this MiniClusterSpec.


        :param pod: The pod of this MiniClusterSpec.  # noqa: E501
        :type pod: PodSpec
        """

        self._pod = pod

    @property
    def size(self):
        """Gets the size of this MiniClusterSpec.  # noqa: E501

        Size (number of job pods to run, size of minicluster in pods)  # noqa: E501

        :return: The size of this MiniClusterSpec.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this MiniClusterSpec.

        Size (number of job pods to run, size of minicluster in pods)  # noqa: E501

        :param size: The size of this MiniClusterSpec.  # noqa: E501
        :type size: int
        """

        self._size = size

    @property
    def tasks(self):
        """Gets the tasks of this MiniClusterSpec.  # noqa: E501

        Total number of CPUs being run across entire cluster  # noqa: E501

        :return: The tasks of this MiniClusterSpec.  # noqa: E501
        :rtype: int
        """
        return self._tasks

    @tasks.setter
    def tasks(self, tasks):
        """Sets the tasks of this MiniClusterSpec.

        Total number of CPUs being run across entire cluster  # noqa: E501

        :param tasks: The tasks of this MiniClusterSpec.  # noqa: E501
        :type tasks: int
        """

        self._tasks = tasks

    @property
    def users(self):
        """Gets the users of this MiniClusterSpec.  # noqa: E501

        Users of the MiniCluster  # noqa: E501

        :return: The users of this MiniClusterSpec.  # noqa: E501
        :rtype: list[MiniClusterUser]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this MiniClusterSpec.

        Users of the MiniCluster  # noqa: E501

        :param users: The users of this MiniClusterSpec.  # noqa: E501
        :type users: list[MiniClusterUser]
        """

        self._users = users

    @property
    def volumes(self):
        """Gets the volumes of this MiniClusterSpec.  # noqa: E501

        Volumes accessible to containers from a host  # noqa: E501

        :return: The volumes of this MiniClusterSpec.  # noqa: E501
        :rtype: dict(str, MiniClusterVolume)
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this MiniClusterSpec.

        Volumes accessible to containers from a host  # noqa: E501

        :param volumes: The volumes of this MiniClusterSpec.  # noqa: E501
        :type volumes: dict(str, MiniClusterVolume)
        """

        self._volumes = volumes

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MiniClusterSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MiniClusterSpec):
            return True

        return self.to_dict() != other.to_dict()
